import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { CodeLine } from "./CodeLine";
/**
 * 顯示完整程式碼區塊，支援多行語法 token 與行號顯示。
 *
 * @template T 元件渲染類型，預設為 <span>
 * @param props.tokenLines 所有程式碼行的 token 陣列
 * @param props.showLineNumbers 是否顯示行號，預設為 true
 * @param props.lineNumberStyle 行號的自訂樣式
 * @param props.theme 主題
 * @param rest 其他傳遞給 <pre> 的屬性
 * @returns JSX 元素，呈現語法高亮的程式碼區塊
 */
export const CodeBlock = ({ tokenLines, showLineNumbers = true, lineNumberStyle, autoWrap, theme, ...rest }) => {
    return (_jsx("pre", { ...rest, style: { margin: 0, padding: 0, overflowX: "auto" }, children: _jsx("table", { style: { borderCollapse: "collapse", width: "100%" }, children: _jsx("tbody", { children: tokenLines.map((line, index) => (_jsxs("tr", { children: [showLineNumbers && (_jsx("td", { style: {
                                paddingInline: "0.5rem",
                                textAlign: "right",
                                whiteSpace: "pre",
                                fontVariantNumeric: "tabular-nums",
                                color: "#888",
                                userSelect: "none",
                                ...lineNumberStyle,
                            }, children: index + 1 })), _jsx("td", { style: { width: "100%" }, children: _jsx(CodeLine, { theme: theme, tokens: line, autoWrap: autoWrap }) })] }, index))) }) }) }));
};
CodeBlock.displayName = "CodeBlock";
