import { jsx as _jsx } from "react/jsx-runtime";
import { CodeToken } from "./CodeToken";
/**
 * 渲染單一程式碼行，包含多個語法 token。
 *
 * @template T 元件渲染類型，例如 <code>、<span> 等
 * @param props.tokens 該行所包含的語法 token 陣列
 * @param props.style 自訂樣式，會與 whiteSpace: pre-wrap 合併
 * @param props.theme 主題
 * @param prop.autoWrap 是否自動換行
 * @param rest 其他 HTMLAttributes
 * @returns JSX 元素，呈現語法 token 的單行程式碼
 */
export const CodeLine = ({ style, tokens, theme, autoWrap = true, ...rest }) => {
    return (_jsx("code", { ...rest, style: {
            whiteSpace: autoWrap ? "pre-wrap" : "nowrap",
            ...style,
        }, children: tokens.map((token, index) => (_jsx(CodeToken, { theme: theme, ...token }, index))) }));
};
CodeLine.displayName = "CodeLine";
